@@ -50,7 +50,7 @@ namespace Breeze
         static Button *create(KDecoration2::DecorationButtonType type, KDecoration2::Decoration *decoration, QObject *parent);
 
         //* render
-        virtual void paint(QPainter *painter, const QRect &repaintRegion) Q_DECL_OVERRIDE;
+        virtual void paint(QPainter *painter, const QRect &repaintRegion) override;
 
         //* flag
         enum Flag
